@@ -1,6 +1,6 @@
 package Bundle::DadaMailXXL;
 
-$VERSION = '0.0.6';
+$VERSION = '0.0.7';
 
 1;
 
@@ -52,8 +52,6 @@ Class::Accessor::Chained::Fast
 
 Data::Page
 
-Data::PageSet
-
 Date::Format
 
 Digest 
@@ -160,7 +158,9 @@ Text::Balanced
 
 PHP::Session
 
-Scalar-List-Utils
+Scalar::Util
+
+List::Util 
 
 Text::CSV
 
